//
//  ViewController.m
//  iOSDemo
//
//  Created by zhuxun.lx on 2022/11/28.
//

#import "ViewController.h"
#import "CallApiClient.h"

@interface ViewController ()
@property(nonatomic,strong) UITextView *hintTextView;
@property(nonatomic,strong) UIButton *callApiBtn;
@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    self.hintTextView = [[UITextView alloc] initWithFrame:CGRectMake(0, 10, 320, 320)];
    self.hintTextView.text = @"本示例是以RecognizeBankCard为例。如果想调用视觉智能开放平台其他能力，请修改以下几点：\n\nTool/CallApiClient.m文件中，ACCESS_KEY_ID、ACCESS_KEY_SECRET。recognizeBankCardWithImageUrl函数中的bodyDict[@\"Action\"]、endpoint、apiVersion参数及bodyDict[@\"ImageURL\"]这一行所代表的业务参数。\n\n例如您想使用通用分割，其文档为https://help.aliyun.com/document_detail/151960.html，可以知道该能力属于分割抠图类目，能力名称为SegmentCommonImage，则可以将endpoint改为imageseg.cn-shanghai.aliyuncs.com，bodyDict[@\"Action\"]改为SegmentCommonImage，apiVersion刚好为2019-12-30不用改，bodyDict[@\"ImageURL\"]参数名也刚好为ImageURL不用改。注意，获取结果的时候，需要获取ImageURL，其含义也不是银行卡号，而是分割后的图片地址。";
    self.hintTextView.editable = false;
    [self.view addSubview:self.hintTextView];
    self.callApiBtn = [UIButton buttonWithType:UIButtonTypeSystem];
    self.callApiBtn.frame = CGRectMake(140, 320, 80, 30);
    [self.callApiBtn setTitle:@"开始调用" forState:UIControlStateNormal];
    [self.callApiBtn addTarget:self action:@selector(callApi) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:self.callApiBtn];
}

/**
 * 调用API
 */
- (void)callApi {
    
    NSString* imageUrl = @"http://viapi-test.oss-cn-shanghai.aliyuncs.com/viapi-3.0domepic/ocr/RecognizeBankCard/yhk1.jpg";
    [CallApiClient recognizeBankCardWithImageUrl:imageUrl responseBlock:^(NSDictionary * _Nonnull data, NSError * _Nonnull error) {
        if (error) {
            if ([error.localizedDescription containsString:@"InvalidAccessKeyId.NotFound"]) {
                [self alertInfomation:@"请求报错，请检查您代码中的YOUR_ACCESS_KEY_ID和YOUR_ACCESS_KEY_SECRET是否已经修改正确。"];
            } else if([error.localizedDescription containsString:@"InvalidApi.NotPurchase"]) {
                [self alertInfomation:@"请求报错，您的账号未开通视觉智能开放平台相应类目，请进行开通：https://help.aliyun.com/document_detail/465341.html"];
            } else if([error.localizedDescription containsString:@"Unauthorized"]) {
                [self alertInfomation:@"请求报错，您的子账号未授予AliyunVIAPIFullAccess权限，请参考https://help.aliyun.com/document_detail/145025.html"];
            } else if([error.localizedDescription containsString:@"InvalidAction.NotFound"]) {
                [self alertInfomation:@"请求报错，请检查您调用的API和类目是否匹配，API和类目的关系请参考：https://help.aliyun.com/document_detail/465341.html，和访问的域名是否匹配，类目和域名的关系请参考：https://help.aliyun.com/document_detail/143103.html"];
            } else {
                [self alertInfomation:error.localizedDescription];
            }
        } else {
            // 获取银行卡号，这里只是示例，请根据文档获取自己想要的出参
            NSString* cardNumber = [data objectForKey:@"CardNumber"];
            [self alertInfomation:[NSString stringWithFormat:@"银行卡号：%@", cardNumber]];
        }
    }];
}

/**
 显示alert
 */
-(void)alertInfomation:(NSString*)msg {
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"警告" message:msg preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"确定" style:UIAlertActionStyleCancel handler:^(UIAlertAction * _Nonnull action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

@end
